SystemOrganization addCategory: #'CS528-WebSetback'!

WAFileLibrary subclass: #SetbackFiles
	instanceVariableNames: ''
	classVariableNames: 'Unmatched'
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

Object subclass: #SetbackWebSocketHandler
	instanceVariableNames: 'webSockets lock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

!SetbackWebSocketHandler class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/7/2013 23:27'!
name: clientName port: aPort
	^ self new
	name: clientName;
	port: aPort;
	yourself.! !

!SetbackWebSocketHandler class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/7/2013 19:28'!
on: aBlock
	^ self new
	block: aBlock;
	yourself.! !

!SetbackWebSocketHandler methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 20:47'!
distributeMessage: textMessage 
	"Send message to all client WebSockets that we know."
	lock critical: [
		webSockets do: [ :each |
			[ each sendMessage: textMessage]
				on: NetworkError 
				do: [ :exception |
					"We can ignore this (instead of #unregister:-ing the offender), 
					since the listener process (see #value:) will do the right thing" 
					each log debug: [ exception printString, ' in ditributeMessage, ignoring' ] ] ] ]
		"(FLSerializer serializeToByteArray:  (textMessage, ' ' , i asString))"! !

!SetbackWebSocketHandler methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/8/2013 14:52'!
initialize
	webSockets := OrderedCollection new.
	lock := Mutex new.! !

!SetbackWebSocketHandler methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/8/2013 14:52'!
register: clientWebSocket
	lock critical: [
		webSockets add: clientWebSocket ]! !

!SetbackWebSocketHandler methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/8/2013 14:53'!
unregister: clientWebSocket
	lock critical: [
		webSockets remove: clientWebSocket ifAbsent: [ ] ]! !

!SetbackWebSocketHandler methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 14:00'!
value: webSocket
	[
	self register: webSocket.
	webSocket runWith: [ :message |	
		webSocket log info: [ 'Received message: ', message printString, ', echoing' ]. ] ] 
	on: ConnectionClosed 
	do: [ webSocket log debug: 'Ignoring connection close, done' ].
	
"textMessage := FLMaterializer materializeFromByteArray: (byteArrayMessage)."! !

Object subclass: #WebsocketUtilities
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

!WebsocketUtilities class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 23:03'!
RegisterServer
ZnServer startDefaultOn: 1701.
ZnServer default logToTranscript.
ZnServer default delegate map: 'ws-setback' to:(ZnWebSocketDelegate map: 'ws-setback' to: SetbackWebSocketHandler new).! !

!WebsocketUtilities class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 23:04'!
StopServer
	ZnServer stopDefault.! !

!WebsocketUtilities class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 18:55'!
distributeMessage: aMessage
	(ZnServer default delegate prefixMap at: 'ws-setback')  handler distributeMessage: aMessage.! !

WAComponent subclass: #GameConfigurationComponent
	instanceVariableNames: 'gameVariant winningStrategyVariant'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

!GameConfigurationComponent class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:40'!
register
	WAAdmin register: self asApplicationAt: 'GameConfig'.! !

!GameConfigurationComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 22:02'!
cancel
    self answer:false.! !

!GameConfigurationComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 22:53'!
renderContentOn: html
	| noGarbagePoints standard firstToEleven |
	noGarbagePoints := 'No Garbage Points'.
	standard := 'Standard'.
	firstToEleven := 'First To Eleven'.	
	(WebSetback setbackGame phaseOrderName = #StandardPhaseOrder) ifTrue:[ gameVariant := standard]
		ifFalse:[gameVariant := noGarbagePoints].
		
	(WebSetback setbackGame winnerStrategyName = #StandardWinStrategy) ifTrue:[ winningStrategyVariant := standard]
		ifFalse:[winningStrategyVariant := firstToEleven].		
		
		
	html
		form: [ 
			html div
				class: 'highlight';
				with: [ 
							html text: 'Scoring Mode: '.
							html select
								list: #('No Garbage Points' 'Standard');
								selected: gameVariant;
								callback: [ :value | 
											value = standard
												ifTrue: [ gameVariant := standard ]
												ifFalse: [ gameVariant := noGarbagePoints ] ].
							html break.
							html text: ' Winning Strategy: '.
							html select
								list: #('First To Eleven' 'Standard');
								selected: winningStrategyVariant;
								callback: [ :value | 
											value = standard
												ifTrue: [ winningStrategyVariant := standard ]
												ifFalse: [ winningStrategyVariant := firstToEleven ] ].
							html break.
							self renderSaveOn: html ] ]! !

!GameConfigurationComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 22:02'!
renderSaveOn: html
	   html submitButton on: #cancel of: self. 
 	   html render: '    '.
	   html submitButton on: #save of: self! !

!GameConfigurationComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 22:29'!
save
	gameVariant = 'Standard' ifTrue:[WebSetback  setbackGame phaseOrder: StandardPhaseOrder new] 
		ifFalse:[WebSetback  setbackGame phaseOrder: StandardNoGarbagePhaseOrder new].
	
	winningStrategyVariant = 'Standard' ifTrue:[WebSetback  setbackGame winnerStrategy: StandardWinStrategy new] 
		ifFalse:[WebSetback   setbackGame winnerStrategy: FirstToElevenWinStrategy new].

	
self answer: true
! !

WAComponent subclass: #GameTableComponent
	instanceVariableNames: 'currentHand'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

!GameTableComponent class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:19'!
currentHand: aHand
	^self new currentHand: aHand.! !

!GameTableComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:24'!
cardImageName: aCard 
	^ aCard suit asString, aCard value asString capitalized, 'Png'.! !

!GameTableComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:20'!
currentHand: aHand
	currentHand:= aHand.! !

!GameTableComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:24'!
renderContentOn: html 
	currentHand ifNotNil: [ 
		self renderTrumpCardOn: html.
		self renderPlayedCardsOn: html.
	]! !

!GameTableComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 21:12'!
renderPlayedCardsOn: html
currentHand currentPhase ifNotNil:[
		currentHand currentPhase currentTrickCardsThrown ifNotNil:[
		currentHand currentPhase currentTrickCardsThrown keysDo:[ :card |
		html anchor
			with:[
		        html image
				url: (SetbackFiles urlOf: (self cardImageName: card));
				width: 60;
				height: 100.
					].
			].
	].].! !

!GameTableComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 21:12'!
renderTrumpCardOn: html
currentHand currentPhase isNil ifTrue: [ html text: '' ]
ifFalse:[
		(currentHand currentPhase shouldDisplayTrump )
		ifTrue:[html text: currentHand currentPhase trump.]
		ifFalse: [ html text: '' ].].
		html break.
! !

WAComponent subclass: #PlayerComponent
	instanceVariableNames: 'player playerId numberMap'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

!PlayerComponent class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 21:09'!
initialize 
	WAAdmin register: self asApplicationAt: 'player'.! !

!PlayerComponent class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 21:20'!
player: aPlayer 
	^self new player: aPlayer.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 23:45'!
cardImageName: aCard 
	^ aCard suit asString, aCard value asString capitalized, 'Png'.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:56'!
getFaceDownCard: aNumber
	^('stack', (numberMap at: aNumber),  'FaceDownPng').! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:03'!
getFaceDownImageWidth: numberOfCards 
	^ (60 + (numberOfCards - 1 * 10)).! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:59'!
initialize 
	super initialize.
	numberMap := Array newFrom: #(#One #Two #Three #Four #Five #Six).
	player ifNil: [ player := (SetbackPlayer name: 'Terry')].! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:16'!
playCard: aCard
	player playCard: aCard.
	WebSetback refreshPage.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 21:07'!
player
	^player.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/15/2013 21:07'!
player: aPlayer 
	player := aPlayer.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 23:05'!
playerId: aPlayerComponentPlayerId
	playerId := aPlayerComponentPlayerId.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 21:25'!
renderBidOn: html 
	player currentBid ifNotNil:[
			html space.
			html text: 'bid:'.
			html text: player currentBid.
		].! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 23:42'!
renderContentOn: html 
	html text: player name .
	self renderBidOn: html.
	html table
		class: 'center';
		with: [
			html tableRow:
			[ 
				html tableHeading 
					class: 'playerCell';
					with: 'Games Won'.
				html tableHeading
					class: 'playerCell';
					with: 'Points Earned'.
				html tableHeading
					class: 'playerCell';
					with: 'Number of cards won' .].
				self renderPlayerDataOn: html.
		].
	self renderPlayerHandOn: html.! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 20:44'!
renderPlayerDataOn: html
		html tableData 
			class: 'playerCell';
			with: (player gamesWon).
		html space.
		html tableData 
			class: 'playerCell';
			with: (player pointsEarned ).
		html space.
		html tableData 
			class: 'playerCell';
			with:  (player cardsWon size).
! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:04'!
renderPlayerHandOn: html
	(player playerId = playerId) ifFalse:[player hand cards size = 0 ifFalse:[ html image url: (SetbackFiles urlOf: (self getFaceDownCard: player hand cards size)); width: (self getFaceDownImageWidth: (player hand cards size));
					height: 100.]]
		ifTrue:[player hand cards do:[ :card |
				html anchor
				callback: [ self playCard: card]; 
				with:[
			        html image
					url: (SetbackFiles urlOf: (self cardImageName: card));
					width: 60;
					height: 100.
					].
					].
				].! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:42'!
renderPlayerHandOnBackup: html
	(player playerId = playerId) ifFalse:[html image url: (SetbackFiles urlOf: #stackSixFaceDownPng)]
		ifTrue:[player hand cards do:[ :card |
			        html image
					url: (SetbackFiles urlOf: (self cardImageName: card));
					width: 60;
					height: 100.
					html anchor callback: [ self player playCard: card]; with: '++'.
					].
				].! !

!PlayerComponent methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 20:38'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: (SetbackFiles urlOf: #playerSetbackCss).! !

WAComponent subclass: #WebSetback
	instanceVariableNames: 'playerName setbakGame aPlayerComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-WebSetback'!

WebSetback class
	instanceVariableNames: 'playerComponents setbackGame currentHand currentGameTable message lastWinner'!

WebSetback class
	instanceVariableNames: 'playerComponents setbackGame currentHand currentGameTable message lastWinner'!

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:33'!
currentGameTable
	^currentGameTable.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:32'!
currentGameTable: aGameTable
	currentGameTable:= aGameTable.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 22:07'!
currentHand
	^currentHand.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 23:30'!
currentHand: aHand
	currentHand := aHand.
	currentGameTable ifNotNil: [ currentGameTable currentHand: aHand.].! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:36'!
initialize 
	super initialize.
	playerComponents := OrderedCollection new.
	setbackGame := SetbackGame setUpStandardGame.
	currentGameTable:= nil.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:12'!
lastWinner
	^lastWinner.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:13'!
lastWinner:aPlayer
	lastWinner:= aPlayer.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:14'!
message
	^message.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:14'!
message: aMessage
	message:= aMessage.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 22:24'!
playerComponents
	^playerComponents! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 21:15'!
refreshPage
	WebsocketUtilities distributeMessage: #refresh.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 23:52'!
register
	WAAdmin register: self asApplicationAt: 'WebSetback'.! !

!WebSetback class methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 21:39'!
setbackGame
	^setbackGame.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 21:50'!
addPlayer
	|player|
	playerName:= self request: 'Player Name: '.
	player := SetbackPlayer name: playerName.
	WebSetback setbackGame addPlayer: player.
	aPlayerComponent := PlayerComponent player: player.
	WebSetback playerComponents add: (aPlayerComponent).
	self refreshPage.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:15'!
advancePhase
	WebSetback currentHand currentPhase ifNotNil: [ 
		(WebSetback currentHand currentPhase remainingTricks = 0) ifTrue:[
			self advanceTwoPhases.
			WebSetback currentHand: WebSetback setbackGame startNewHand. 
			WebSetback message: 'Playing new hand'.
			self advanceTwoPhases.
			"WebSetback currentHand startNextPhase."
		].
	]! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 23:15'!
advanceTwoPhases
WebSetback currentHand startNextPhase.
WebSetback currentHand startNextPhase.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 20:58'!
bid2
	self playerBid:#two.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 20:58'!
bid3
	self playerBid:#three.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 20:59'!
bid4
	self playerBid:#four.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 21:16'!
cancel
    self answer: false.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 22:25'!
children 
	^WebSetback  playerComponents asArray.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 22:15'!
configGame
	(self call: (GameConfigurationComponent  new))
        ifTrue: [
			
		].
	self refreshPage.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:52'!
getCurrentPlayerClassAt: index
	|aComponent|
	WebSetback playerComponents size < index ifTrue:[^'otherPlayerCell'].
	(aPlayerComponent ifNil: [^'otherPlayerCell']).
	aComponent := (WebSetback playerComponents at: index).
	WebSetback currentHand currentPhase ifNil:[^'otherPlayerCell'].
	^(aComponent player = WebSetback currentHand currentPhase nextPlayerToThrow) ifTrue:[^'currentPlayerCell'] ifFalse:[^'otherPlayerCell'].! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:36'!
initialize
	super initialize.	
	WebSetback playerComponents ifNil:[WebSetback  initialize.].
	WebSetback setbackGame ifNil:[WebSetback  initialize.].! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 21:53'!
isCurrentPlayer
	(aPlayerComponent ifNil: [^false]).
	^(aPlayerComponent  player = WebSetback currentHand currentPhase nextPlayerToThrow).! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 22:33'!
isCurrentPlayerAt: index
	|aComponent|
	WebSetback playerComponents size > index ifFalse:[^false].
	(aPlayerComponent ifNil: [^false]).
	aComponent := (WebSetback playerComponents at: index).
	aComponent = aPlayerComponent ifFalse:[^false].
	^(aPlayerComponent player = WebSetback currentHand currentPhase nextPlayerToThrow).! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/10/2013 15:52'!
message
	^message.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 20:58'!
pass
	self playerBid:#pass.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 21:39'!
playerBid: aValue
	aPlayerComponent player makeBid: aValue.
	(aPlayerComponent player = WebSetback currentHand dealer) ifTrue:[
		WebSetback currentHand startNextPhase.
		].
	self refreshPage.
	
! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'RameshKolavenu 7/18/2013 07:19'!
refreshPage
	WebsocketUtilities distributeMessage: #refresh.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/18/2013 22:49'!
renderBidingButtonsOn: html
	|disable|
	WebSetback setbackGame started ifTrue: [ 
	disable := true.
	WebSetback currentHand currentPhase ifNotNil: [ 
		(aPlayerComponent player = WebSetback currentHand currentPhase currentBidder) ifTrue:[disable := false].].
	html space.
	html submitButton disabled: disable; on: #pass of: self.
   	html space.
	html submitButton disabled: disable; on: #bid2 of: self.
	html space.
	html submitButton disabled: disable; on: #bid3 of: self.
	html space.
	html submitButton disabled: disable; on: #bid4 of: self.
	 ].
	! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:54'!
renderContentOn: html
	self renderPageHeaderOn: html.
	html horizontalRule.
	html table: [ self renderMainTableOn: html ].
	html break.
	html horizontalRule.
	html div id: #output! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:59'!
renderGameControlsOn: html
	html
		form: [ 			
			html anchor
				class:'highlight';
				callback: [ self configGame ];
				with: 'Config Game'.		   
			html div class: 'divider'.	
				html anchor
				class:'highlight';
				callback: [ self addPlayer ];
				with: 'Add Player'.
			html div class: 'divider'.	
			self renderStartOverOn: html.
			html paragraph:
			[ 
				html break.
				self renderBidingButtonsOn: html 
			].
		]! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 21:23'!
renderGameOn: html
	html render: 'Player name: '.
	html textInput
		id: 'txtMessage';
		callback: [ :value | playerName := value].
! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:17'!
renderMainTableOn: html 
	self advancePhase.
	html 
		tableRow: 
		[ 
			html tableData
				class: 'mainCell';
				with: [self renderGameControlsOn: html].
			html space.	
			html tableData
				class: 'mainCell';
				class: (self getCurrentPlayerClassAt: 1);
				with: [self renderPlayerCellOn: html at: 1].
			html space.
			html tableData
				class: 'mainCell';
				with:  [self renderNotificationOn: html ].
		];
		tableRow: 
		[ 
			html tableData
				class: 'mainCell';
				class: (self getCurrentPlayerClassAt: 3);
				with: [self renderPlayerCellOn: html at: 3].
			html space.
			html tableData
				class: 'mainCell';			
				with: WebSetback currentGameTable.
			html space.
			html tableData	
				class: 'mainCell';
				class: (self getCurrentPlayerClassAt: 2);
				with: [self renderPlayerCellOn: html at: 2].
		].! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:13'!
renderNotificationOn: html
	WebSetback lastWinner ifNotNil:[html render: WebSetback lastWinner name].
	html render: WebSetback message.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 21:41'!
renderPageHeaderOn: html
	html paragraph
		class: 'header';
		with: [ 
					html strong with: [ html text: 'Welcome to CS528 - Setback project ' ].
					html break.
					html emphasis
						class: 'headerFont1';
						with: ' Implemented by Ramesh, Terry, and Mehrdad' ]! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/17/2013 22:08'!
renderPlayerCellOn: html at: index
	| playerComponent |
	WebSetback playerComponents size > (index - 1) ifTrue: [ 
	playerComponent := WebSetback playerComponents at: index. 
	WebSetback currentHand dealer = playerComponent player ifTrue:[html render: 'Dealer: '].
	aPlayerComponent ifNotNil: [playerComponent playerId: (aPlayerComponent player playerId)].
	html render: playerComponent.
	].! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'RameshKolavenu 7/17/2013 21:53'!
renderStartOverOn: html
	   html space.
	   html submitButton on: #startGame of: self.! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:28'!
save! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/13/2013 16:56'!
send
	"webSocket sendMessage: (FLSerializer serializeToByteArray: textMessage)."! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:17'!
setGameScoreVariant: value
	self halt.
	 value = 'Standard'
		ifTrue: [ WebSetback setbackGame phaseOrder: StandardPhaseOrder new ]
		ifFalse: [ WebSetback setbackGame phaseOrder: StandardNoGarbagePhaseOrder new ]! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/22/2013 21:17'!
setGameScoreVariantStandard: value
	value = 'Standard'
		ifTrue: [ WebSetback setbackGame phaseOrder: StandardPhaseOrder new ]
		ifFalse: [ WebSetback setbackGame phaseOrder: StandardNoGarbagePhaseOrder new ]! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/19/2013 23:15'!
startGame
	WebSetback playerComponents  size = 3 ifTrue: [ 
		WebSetback currentHand: WebSetback setbackGame startGame.
		self advanceTwoPhases.
		WebSetback currentGameTable: (GameTableComponent currentHand: WebSetback currentHand).
		WebSetback message: 'Game started'.
		self refreshPage.
	].! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/13/2013 16:55'!
updateOutput: html
"
	| rcvMessage |
		[[rcvMessage := FLMaterializer materializeFromByteArray: webSocket readMessage.
		Transcript show: rcvMessage; cr.
		html paragraph: [html text: rcvMessage.] repeat. ] fork."! !

!WebSetback methodsFor: 'as yet unclassified' stamp: 'MehrdadBiglari 7/16/2013 20:39'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot javascript url: (SetbackFiles urlOf: #webSocketJs).
	anHtmlRoot stylesheet url: (SetbackFiles urlOf: #setbackCss).
"	
	[ webSocket runWith: [ :msg |
			webSocket log info: [ 'Received message: ', msg printString ].]  ] 
		on: ConnectionClosed 
		do: [
			webSocket log debug: 'Connection close, cleaning up'.].
"		! !
WebSetback initialize!
PlayerComponent initialize!
